<?php


/**
 * Informationsseite über den Status von PSTN Ports, SIP Konten, Cloud-Verbindung, usw.
 * @author Miguel Palmer <mp@beronet.com>
 */

class State {

	private		$post_attr,
			$post_checked = 0;

	private		$isRequestRejected = 0,
			$reasonRejected = array();

	/**
	 * Constructor
	 */
	function __construct($m, $get = array(), $post = array(), $session = array()) {

		// if an error occurs during a background script or in other modules (badly redirected)
                if (isset($get['error'])) {
                        $this->isRequestRejected = 1;
                        $this->reasonRejected = array('request' => $get['request'], 'checkor' => $get['checkor'], 'key' => $get['key']);
                        unset($get['error'], $get['request'], $get['checkor'], $get['key']);
                }

		// why these unset only to this module
		unset($post['gui_mode'], $post['lang'], $post['y'], $post['x']);

		if (count($post) > 0) {
			$list_post = array('lif_gsm' => 'int>=0', 'port_gsm' => 'int>=0', 'port' => 'int>=0'); 

			$this->post_checked = 1;
			$this->post_attr = Helper::sanitizePost($post, $list_post, $this->post_checked, $this->reasonRejected);

			$this->isRequestRejected = !$this->post_checked;
		}
	}

	/**
	 * Generates the HTML page
	 * @return string
	 */
	function display() {

		require_once "./includes/isgwtelnet.php";
                $name="STATE_TITLE_DIS";
		include('./includes/header.php');
		require_once("./includes/lang.php");
		require_once("./includes/variables.php");

		$ba = new beroAri();
		$isgw = new isgwtelnet();
		$result=$isgw->isgw_login();
		if ($result==false) {
			$ret.="<div class='text-center' style='color:red;'>".STATE_ISWG_ERROR_DIS."</div>";
			return $ret;
		}
		$isdnresult=$isgw->isgw_isdnstate();
		$analogresult=$isgw->isgw_analogstate();
		$casresult=$isgw->isgw_casstate();
		$sipresult=$isgw->isgw_sipstate();
		$pcm_result=$isgw->isgw_pcmstate();
		$beroCapi_result=$isgw->isgw_berocapistate();
		$gsm_result=$isgw->isgw_gsmstate();
		$adv_gsm_result=$isgw->isgw_adv_gsmstate();

		if ($this->post_checked && isset($this->post_attr['port'])){
			$ret.= "<br/><div class='text-center' style='color:red;'>".$isgw->port_restart($this->post_attr['port'])."</div>";
		}
		if ($this->post_checked && isset($this->post_attr['lif_gsm'])){
			$isgw->port_restart_gsm($this->post_attr['port_gsm'],$this->post_attr['lif_gsm']);
			$ret.= "<br/><div class='text-center' style='color:red;'>Restarted</div>";
		}
		if ($this->isRequestRejected) {
			$ret .= Helper::displayErrorMessage($this->reasonRejected['request'], $this->reasonRejected['checkor'], $this->reasonRejected['key']);
		}

		//Die Informationen von dem Status von ISDN werden in eine Tabelle formatiert und in der
		//return-Variable der Funktion gespeichert

		$rows = "";
		$rows = explode("\n", $isdnresult);
		if (count($rows)>=4){
			$l1=file("/proc/l1_stats");
			foreach($l1 as $key => $value){
				$v=explode(";",$value);
				foreach($v as $werte){
					$wert=explode("=",$werte);
					if ($wert[0]=="port") {$port=$wert[1]; $l1_stats[$wert[1]]="";}
					if ($wert[0]=="physw") {$l1_stats[$port].="Physical Link Switch: ".$wert[1]."<br>";}
					if ($wert[0]=="crc") {$l1_stats[$port].="CRC Error: ".$wert[1]."<br>";}
					if ($wert[0]=="fr") {$l1_stats[$port].="Frame Resent: ".$wert[1]."<br>";}
					if ($wert[0]=="fs") {$l1_stats[$port].="Frame Resync: ".$wert[1]."<br>";}
					if ($wert[0]=="los") {$l1_stats[$port].="Loss of Signal: ".$wert[1];}
				}
			}

			$l2=file("/proc/l2_stats");
			foreach($l2 as $key => $value){
				$v=explode(";",$value);
				foreach($v as $werte){
					$wert=explode("=",$werte);
					if ($wert[0]=="port") {$port=$wert[1]; $l2_stats[$wert[1]]="";}
					if ($wert[0]=="mdl") {$l2_stats[$port].="L2 Error: ".$wert[1]."<br>";}
					if ($wert[0]=="frm") {$l2_stats[$port].="L2 Frame Error: ".$wert[1]."<br>";}
				}
			}

			$ret .= "<br><br>";
			$ret .= "<table class='table table-striped table-bordered' style='width:95% !important; margin:auto;'>";
			$ret .= "<th colspan='6' class='text-center'>".STATE_ISDN_STATUS_DIS."</th>";
			$ret .= "<tr><td><b>".STATE_PORT_DIS."</b></td><td><b>".STATE_TYPE_DIS."</b></td><td><b>".STATE_PROT_DIS."</b></td>";
			$ret .= "<td><b>".STATE_L2LINK_DIS."</b></td><td><b>".STATE_L1LINK_DIS."</b></td><td></td></tr>";

			foreach ($rows as $value){
				$pos=strpos($value,"Port");
				if($pos !== false){
					$ret .= "<tr>";
					$tmp = explode("Port ", $value);
					$port = explode(" Type", $tmp[1]);
					$ret .= "<td>" . $port[0] . "</td>";
					$type = explode(" Prot.", $port[1]);
					$ret .= "<td>" . $type[0] . "</td>";
					$prot = explode(" L2Link", $type[1]);
					$ret .= "<td>" . $prot[0] . "</td>";
					$l2link = explode(" L1Link:", $prot[1]);
					$l2link[0] = str_replace(" ", "", $l2link[0]);
					if ($l2link[0] == "UP") {
						$ret .= "<td><img src='./includes/images/punkt_gruen.gif' onmouseover=\"Tip('UP<br>" . $l2_stats[$port[0]] . "')\" onmouseout='UnTip()'></td>";
					} else {
						$ret .= "<td><img src='./includes/images/punkt_rot.gif' onmouseover=\"Tip('DOWN<br>" . $l2_stats[$port[0]] . "')\" onmouseout='UnTip()'></td>";
					}
					$l1link = explode(" Blocked:", $l2link[1]);
					$l1link[0] = str_replace(" ", "", $l1link[0]);
					if ($l1link[0] == "UP") {
						$ret .= "<td><img src='./includes/images/punkt_gruen.gif' onmouseover=\"Tip('UP<br>" . $l1_stats[$port[0]] . "')\" onmouseout='UnTip()'></td>";
					} else {
						$ret .= "<td><img src='./includes/images/punkt_rot.gif' onmouseover=\"Tip('DOWN<br>" . $l1_stats[$port[0]] . "')\" onmouseout='UnTip()'></td>";
					}
					$ret .= "<td><form method='POST'>
								<input type='hidden' name='port' value='".$port[0]."'>
								<input type='submit' class='btn btn-default' value='".BUTTON_RESTART."'></form></td></tr>";
				}//endif
			}//endforeach

			$ret .= "</table><br/><br/>";
		}

		//Die Informationen von dem Status von ANALOG werden in eine Tabelle formatiert und in der
		//return-Variable der Funktion gespeichert

		$rows = "";
		$rows = explode("\n", $analogresult);
		if (count($rows)>=4){
			$ret .= "<br><br>";
			$ret .= "<table class='table table-striped table-bordered' style='width:95% !important; margin:auto;'>";
			$ret .= "<th colspan='6' class='text-center'>".STATE_ANALOG_STATUS_DIS."</th>";
			$ret .= "<tr><td><b>".STATE_PORT_DIS."</b></td><td><b>".STATE_TYPE_DIS."</b></td><td><b>".STATE_STATE_DIS."</b></td>";
			$ret .= "<td><b>".STATE_LINE_VOLTAGE_DIS."</b></td></tr>";

			foreach ($rows as $value){
				$pos=strpos($value,"Port");
				if($pos !== false){
					$ret .= "<tr>";
					
					$fields = explode("\t", $value);
					$tmp = explode("Port ", $value);
					$port = explode("type:", $tmp[1]);
					$ret .= "<td>" . $port[0] . "</td>";
					$type = explode("state:", $port[1]);
					$broken="<b><font color='red'>".$type[0]."</font></b>";
					$ret .= "<td>" .((trim($type[0])!="BROKEN") ? $type[0] : $broken) . "</td>";
					
					$state = explode("linevoltage:", $type[1]);
					
					$admin_offset = explode(":", $fields[6]);
					
					if ($admin_offset[1] == "1") {
						$shown_state = "FXO_ADMINISTRATIVE_OFFHOOK";
					}
					else {
						$shown_state = $state[0];
					}
					
					if (trim($shown_state)=="UNKNOWN" || trim($shown_state)=="FXS_LOWPOWER"){
						$shown_state="FXS_LOWPOWER";
						$ret .= "<td onmouseover=\"Tip('" . STATE_LOWPOWER_DIS. "')\" onmouseout='UnTip()'>" . $shown_state . "</td>";
					}
					else {
						$ret .= "<td>" . $shown_state . "</td>";
					}
					$linevoltage = explode("pol:", $state[1]);
					$pol = explode("rtlc:", $linevoltage[1]);


					if ($linevoltage[0] >= 30) {
						$ret .= "<td><img src='./includes/images/punkt_gruen.gif' onmouseover=\"Tip('UP<br>" . STATE_LINE_VOLTAGE_DIS. ":". $linevoltage[0] . "<br>".STATE_POLARITY_DIS.":" .  $pol[0] . "')\" onmouseout='UnTip()'></td>";
					} else {
						$ret .= "<td><img src='./includes/images/punkt_rot.gif' onmouseover=\"Tip('DOWN<br>" . STATE_LINE_VOLTAGE_DIS. ":". $linevoltage[0] . "<br>".STATE_POLARITY_DIS.":" .  $pol[0] . "')\" onmouseout='UnTip()'></td>";
					}
					$ret.="</tr>";
				}//endif
			}//endforeach

			$ret .= "</table><br/><br/>";
		}

		//Die Informationen von dem Status von CAS werden in eine Tabelle formatiert und in der
		//return-Variable der Funktion gespeichert

		$rows = "";
		$rows = explode("\n", $casresult);
		if (count($rows)>=3){
			$ret .= "<br><br>";
			$ret .= "<table class='table table-striped table-bordered' style='width:95% !important; margin:auto;'>";
			$ret .= "<th colspan='2' class='text-center'>".STATE_CAS_STATUS_DIS."</th>";
			$ret .= "<tr><td><b>".STATE_PORT_DIS."</b></td><td><b>".STATE_STATE_DIS."</b></td></tr>";

			foreach ($rows as $value){
				$row=  explode("\t", $value);
                                if (count($row)>=2){
					$ret .= "<tr>";
					$port = $row[0];
					$ret .= "<td>" . $port . "</td>";
					$state = $row[1];
					if ($state==1) {
						$ret .= "<td><img src='./includes/images/punkt_gruen.gif' onmouseover=\"Tip('UP<br>" . STATE_LINE_VOLTAGE_DIS. ":". $linevoltage[0] . "<br>".STATE_POLARITY_DIS.":" .  $pol[0] . "')\" onmouseout='UnTip()'></td>";
					} else {
						$ret .= "<td><img src='./includes/images/punkt_rot.gif' onmouseover=\"Tip('DOWN<br>" . STATE_LINE_VOLTAGE_DIS. ":". $linevoltage[0] . "<br>".STATE_POLARITY_DIS.":" .  $pol[0] . "')\" onmouseout='UnTip()'></td>";
					}
					$ret.="</tr>";
				}//endif
			}//endforeach

			$ret .= "</table><br/><br/>";
		}

		//Die Informationen von dem Status von GSM werden in eine Tabelle formatiert und in der
		//return-Variable der Funktion gespeichert

		$rows = "";
		$rows = explode("\n", $gsm_result);
		if (count($rows)>=4){
			$ret .= "<br><br>";
			$ret .= "<table class='table table-striped table-bordered' style='width:95% !important; margin:auto;'>";
			$ret .= "<th colspan='4' class='text-center'>".STATE_GSM_STATUS_DIS."</th>";
			$ret .= "<tr><td><b>".STATE_PORT_DIS."</b></td><td><b>".STATE_PROVIDER_DIS."</b></td><td><b>".STATE_REG_STATUS_DIS."</b></td>";
			$ret .= "<td><b>".STATE_SIGNAL_QUALITY_DIS."</b></td></tr>";
			$where="";
			foreach ($rows as $value){
				$pos=strpos($value,"Port");
				if($pos !== false){
					$ret .= "<tr>";
					
					$port = "0";
					$provider = "unknown";
					$counter = "-1";
					$regstatus = "3";
					$rssi= "-100";
					$ber = "0";
					$tech = "unknown";
					$fields = explode("\t", $value);
					if (count ($fields) == 6 || count ($fields) == 7) {
						$vals = explode(" Port ", $fields[0]);
						if (count ($vals) == 2) {
							$port = trim ($vals[1]);
						}
						$vals = explode("Provider:", $fields[1]);
						if (count ($vals) == 2) {
							$provider = trim ($vals[1]);
						}
						$vals = explode("Pin Counter:", $fields[2]);
						if (count ($vals) == 2) {
							$counter = trim ($vals[1]);
						}
						$vals = explode("Reg Status:", $fields[3]);
						if (count ($vals) == 2) {
							$regstatus = trim ($vals[1]);
						}
						$vals = explode("RSSI:", $fields[4]);
						if (count ($vals) == 2) {
							$rssi = trim ($vals[1]);
						}
						$vals = explode("BER:", $fields[5]);
						if (count ($vals) == 2) {
							$ber = trim ($vals[1]);
						}
						$vals = explode("Tech:", $fields[6]);
						if (count ($vals) == 2) {
							$tech = trim ($vals[1]);
						}
					}

					$lines=explode("\n",$adv_gsm_result);
					$imsi="";
					$imei="";
					for ($i=0;$i<=count($lines);$i++){
						if (trim($lines[$i])=="GSM PORT ".trim($port[0]).":"){
							$imsi=explode(": ",$lines[$i+1]);
							$imsi="IMSI: ".$imsi[1]."<br>";
							$imei=explode(": ",$lines[$i+2]);
							$imei="IMEI: ".$imei[1];
							break;
						}
					}

					$ret .= "<td onmouseover=\"Tip('".$imsi.$imei."')\" onmouseout='UnTip()'>" . $port . "</td>";
					$ret .= "<td onmouseover=\"Tip('" . STATE_PIN_COUNTER_DIS. ":". $counter . "')\" onmouseout='UnTip()'>" . $provider  . "</td>";
					if (trim($regstatus)=="NOT READY"){ $src="./includes/images/punkt_rot.gif"; $tTip='DOWN<br>Not ready';}
					elseif (trim($regstatus)==0){ $src="./includes/images/punkt_rot.gif"; $tTip='DOWN<br>'.STATE_REG_STATUS0_DIS . "<br>" . $tech;}
					elseif (trim($regstatus)==1){ $src="./includes/images/punkt_gruen.gif"; $tTip='UP<br>'.STATE_REG_STATUS1_DIS . "<br>" . $tech;}
					elseif (trim($regstatus)==2){ $src="./includes/images/punkt_rot.gif"; $tTip='DOWN<br>'.STATE_REG_STATUS2_DIS . "<br>" . $tech;}
					elseif (trim($regstatus)==3){ $src="./includes/images/punkt_rot.gif"; $tTip='DOWN<br>'.STATE_REG_STATUS3_DIS . "<br>" . $tech;}
					elseif (trim($regstatus)==4){ $src="./includes/images/punkt_rot.gif"; $tTip='DOWN<br>'.STATE_REG_STATUS4_DIS . "<br>" . $tech;}
					elseif (trim($regstatus)==5){ $src="./includes/images/punkt_gruen.gif"; $tTip='UP<br>'.STATE_REG_STATUS5_DIS . "<br>" . $tech;}

					$ret .= "<td onmouseover=\"Tip('$tTip')\" onmouseout='UnTip()'><img src='".$src."'></td>";
					
					$rssiNumber=$rssi;
					
					if ($rssiNumber[0]==-1 || $rssiNumber[0]==99) $signal="-";
					elseif ($rssiNumber[0]>-60) $signal="VERY HIGH";
					elseif ($rssiNumber[0]<=-60 && $rssiNumber[0]>-75) $signal="HIGH";
					elseif ($rssiNumber[0]<=-75 && $rssiNumber[0]>-100) $signal="OK";
					elseif ($rssiNumber[0]<=-100) $signal="LOW";
					
					if ($regstatus == "NOT READY") {
						$signal = "---";
					}
					($where=="") ? $where="port=".$port[0] : $where.=" or port=".$port[0];
					$ret .= "<td onmouseover=\"Tip('" . STATE_RSSI_DIS . ":" . $rssi . "<br>" . STATE_BER_DIS . ":" . $ber . "')\" onmouseout='UnTip()'>" . $signal . "</td></tr>";
				}//endif
			}//endforeach
			$ret .= "<tr><td colspan='4' class='text-center'>";
			
			for ($i = 0; $i < 2; $i++) {
				($i == 0) ? $mtype = "gsm" : $mtype = "lte";
				$query=$ba->select("select distinct lif from " . $mtype . " where ".$where);
				while ($entry = $ba->fetch_array($query)) {
					$ret .= "<form method='POST'>";
					$ret .= "<input type='hidden' name='lif_gsm' value='".$entry['lif']."'>";
					$queryPort=$ba->select("select port from $mtype where lif=".$entry['lif']);
					while ($entryPort = $ba->fetch_array($queryPort)) {
						$ret .= "<input type='hidden' name='port_gsm[]' value='".$entryPort['port']."'>";
					}
					$ret .= "<input type='submit' class='btn btn-default' onclick='document.getElementById(\"wait_div\").style.display=\"block\";' value='".BUTTON_RESTART." LI ".$entry['lif']."'></form>";
				}
			}

			$ret .= "</td></tr>";
			$ret .= "</table><br/><br/>";
		}



		//Sip Resgistration
		$ret .= "<br/><br/>";
		$ret .= "<table class='table table-striped table-bordered' style='width:95% !important; margin:auto;'>";
		$ret .= "<tr><th colspan='5' class='text-center'>".STATE_REGISTRATION_STATUS_DIS."</th></tr>";
		$ret .= "<tr><td><b>".STATE_ACCOUNTNAME_DIS."</b></td><td><b>".STATE_REGISTRAR_DIS."</b></td><td><b>".STATE_USER_DIS."</b></td>";
		$ret .= "<td><b>".STATE_VALIDATIONSTATUS_DIS."</b></td><td><b>".STATE_REGSTATUS_DIS."</b></td></tr>";

		$rows = explode("\n", $sipresult);
		$i=0;
		foreach ($rows as $value){
			preg_match('/(.+)\s*\=\>(.+)\s*/', $value,$match);
			if (trim($match[1])=="RESPONSECODE") $responsecode = trim($match[2]);
			if (trim($match[1])=="RESPONSECODEVAL") $responsecodeval = trim($match[2]);
			
			if (trim($match[1])=="ACCOUNTNAME") $ret.="<tr><td>".trim($match[2])."</td>";
			if (trim($match[1])=="ADDRESS") $ret.="<td>".trim($match[2])."</td>";
			if (trim($match[1])=="USERNAME") $ret.="<td>".trim($match[2])."</td>";

			if (trim($match[1])=="VALIDATED" && (trim($match[2])=="-1")) $ret .= "<td><img src='./includes/images/punkt_grau.gif' onmouseover=\"Tip('" . TOOLTIP_NOVALIDATION_REQUESTED . "')\" onmouseout='UnTip()'></td>";
			elseif (trim($match[1])=="VALIDATED" && (trim($match[2])=="0")) $ret .= "<td><img src='./includes/images/punkt_rot.gif' onmouseover=\"Tip('DOWN<br>" . $responsecodeval . "')\" onmouseout='UnTip()'></td>";
			elseif (trim($match[1])=="VALIDATED" && (trim($match[2])=="1")) $ret .= "<td><img src='./includes/images/punkt_gruen.gif' onmouseover=\"Tip('UP')\" onmouseout='UnTip()'></td>";
			elseif (trim($match[1])=="VALIDATED")  $ret .= "<td><img src='./includes/images/punkt_grau.gif' onmouseover=\"Tip('Error')\" onmouseout='UnTip()'></td>";

			if (trim($match[1])=="REGSTATUS" && (strstr (trim($match[2]),"NOREGISTER"))) $ret .= "<td><img src='./includes/images/punkt_grau.gif' onmouseover=\"Tip('" . TOOLTIP_NOREGISTRATION_REQUESTED . "')\" onmouseout='UnTip()'></td>";
			elseif (trim($match[1])=="REGSTATUS" && (trim($match[2])=="REGISTERED")) $ret .= "<td><img src='./includes/images/punkt_gruen.gif' onmouseover=\"Tip('UP')\" onmouseout='UnTip()'></td>";
			elseif (trim($match[1])=="REGSTATUS") $ret .= "<td><img src='./includes/images/punkt_rot.gif' onmouseover=\"Tip('DOWN<br>" . $responsecode . "')\" onmouseout='UnTip()'></td>";

			if (preg_match('/^[-]$/',$value)===1) $ret .= "</tr>";
		}
		$ret .= "</table><br/><br/>";

		//PCM Status. Wird nur angezeigt wenn PCM konfiguriert ist
		$ba = new beroAri();
		$pcm_server = $ba->get("pcm_server");
		if ($pcm_server!="0"  && $pcm_server!=""){


			$ret .= "<br/><br/>";
			$ret .= "<table class='table table-striped table-bordered' style='width:95% !important; margin:auto;'>";
			if ($pcm_server=="1")
				$ret .= "<tr><th>".STATE_PCM_SERVER_STATUS_DIS.":</th>";
			else
				$ret .= "<tr><th>".STATE_PCM_CLIENT_STATUS_DIS.":</th>";

			$rows = explode("\n", $pcm_result);
			$status=false;
                        $ip = exec('/sbin/ifconfig eth0 | sed -ne "s/.*inet addr:\(.*\) Bcast.*/\1/p"');
                        define ("ip_address", $ip);
			$ip="";
			for ($j=0;$j < count($rows)-2;$j++){
				$v = explode("\t", $rows[$j]);
				for ($i=0;$i < count($v);$i++){
					if ($i==1 && $j!=0 && $v[$i]!=ip_address){
						$status=true;
						$ip=$v[$i];
					}
				}
			}
			if ($status){
				$ret.="<th><img src='./includes/images/punkt_gruen.gif' onmouseover=\"Tip('UP')\" onmouseout='UnTip()'></th></tr>";
				if ($pcm_server=="1")
					$ret .= "<tr><td>".STATE_PCM_CLIENT_IP_DIS.":</td><td>$ip</td></tr>";
				else
					$ret .= "<tr><td>".STATE_PCM_SERVER_IP_DIS.":</td><td>$ip</td></tr>";
			}else
				$ret.="<th><img src='./includes/images/punkt_rot.gif' onmouseover=\"Tip('DOWN')\" onmouseout='UnTip()'></th></tr>";




			$ret .= "</table>";
		}

		//Die Informationen von dem Status von beroCapi werden in eine Tabelle formatiert und in der
		//return-Variable der Funktion gespeichert

		$rows = "";
		$rows = explode("\n", $beroCapi_result);

		if (count($rows)>=5){
		$ret .= "<br><br>";
		$ret .= "<table class='table table-striped table-bordered' style='width:95% !important; margin:auto;'>";
		$ret .= "<th colspan='3' class='text-center'>".STATE_BEROCAPI_STATUS_DIS."</th>";
		$ret .= "<tr><td><b>".STATE_CAPI_INSTANCE_DIS."</b></td><td><b>".STATE_LICENSE_DIS."</b></td><td><b>".STATE_STATE_DIS."</b></td></tr>";

		foreach ($rows as $value){
			$pos=strpos($value,"VIA URL");
			if($pos !== false){
				$ret .= "<tr>";
				$tmp = explode(":", $value);
				$ret .= "<td>" . $tmp[1] . "</td>";
			}//endif
			$pos=strpos($value,"LICENSE");
			if($pos !== false){
				$tmp = explode(":", $value);
				$license=explode("=",$tmp[1]);
				$ret .= "<td>" . $license[1] . "</td>";
				$ret .= "<td><img src='./includes/images/punkt_gruen.gif' onmouseover=\"Tip('UP')\" onmouseout='UnTip()'></td></tr>";
			}//endif
		}//endforeach


		$ret .= "</table><br/><br/>";
		}
                
                //Cloud status
                $bc = new beroConf('root');
                if ($bc->get("root","cloud_enable")!=""){
                    $ret .= "<br><br>";

                    $ret .= "<table class='table table-striped table-bordered' style='width:95% !important; margin:auto;'>";
                    $ret .= "<th colspan='3' class='text-center'>".STATE_CLOUD_DIS."</th>";
                    $ret .= "<tr><td><b>".STATE_ALIVE_DIS."</b></td>";
                    if ($bc->get("root","cloud_enable")==1 && $ba->get("error")==""){
                      $ret .= "<td ><img src='./includes/images/punkt_gruen.gif' onmouseover=\"Tip('UP')\" onmouseout='UnTip()'></td></tr>";
                    }elseif ($bc->get("root","cloud_enable")==0  || $ba->get("error")!=""){
                        $ret .= "<td onmouseover='Tip(\"DOWN<br>".  htmlentities($ba->get('error'),ENT_QUOTES)."\")' onmouseout='UnTip()'><img src='./includes/images/punkt_rot.gif'></td></tr>";
                    }
                    $ret .= "</table><br/><br/>";
                }
            
        

		//Die Datei sytem.log


		if (is_file("/var/log/system.log")){
			$fileContent=file_get_contents("/var/log/system.log");
			$ret .= "<br><br>";
			$ret .= '<script type="text/javascript">
					window.setInterval("rel()", 10000);
					function rel(){
						$.ajax({ url: \'misc/fileContent.php?filename=/var/log/system.log\', success:
								function(data) {
									var test=false;
									var bottom = $("#systemLog").attr("scrollHeight");
									//alert(bottom);
									//alert($(\'#systemLog\').scrollTop());
									if(($(\'#systemLog\').scrollTop()+200) == parseInt(bottom)){ test=true;}
									$(\'#systemLog\').html(data);
									if (test){
										var bottom = $("#systemLog").attr("scrollHeight");
										$(\'#systemLog\').scrollTop(bottom);
									}
								}
							});
					}
					</script>';

			$ret .= "<div style=' width:90%; font-size: 11pt; font-weight: bold; margin:auto;'>System log</div>
					<div id='systemLog' style='overflow:auto; padding-left:10px; background-color: #F0F0F0; border: 1px solid #CCCCCC;height:200px; width:90%; margin:auto;' >".str_replace("\n","<br/>",$fileContent)."</div>";
			$ret .= '<script type="text/javascript">
						var bottom = $("#systemLog").attr("scrollHeight");
						$(\'#systemLog\').scrollTop(bottom);
					</script>';
		}

		return $ret;
	}

}
?>
